@@ -11,7 +11,6 @@
 ##  copyright (c) 2000-6, Karl W Broman                                 #
 ##                                                                      #
 ##  First version: 09/27/2009                                           #
-##  Last update:   06/20/2017                                           #
 ##  License: GNU General Public License version 3 (June, 2007) or later #
 ##                                                                      #
 #########################################################################
@@ -31,16 +30,17 @@ globalVariables(c("mkt.wrg"))
 ##'
 ##' @param dir directory where the input file is located.
 ##' @param file the name of the input file which contains the data to be read.
+##' @param verbose A logical, if TRUE it output progress status
+##' information.
+##' 
 ##' @return An object of class \code{onemap}, i.e., a list with the following
 ##' components: \item{geno}{a matrix with integers indicating the genotypes
 ##' read for each marker in \code{onemap} fashion. Each column contains data
 ##' for a marker and each row represents an individual.}
 ##'
-##' \item{geno.mmk}{ a matrix with
-##' integers indicating the genotypes read for each marker in
 ##' \code{MAPMAKER/EXP} fashion, i.e., 1, 2, 3: AA, AB, BB, respectively; 3, 4:
 ##' BB, not BB, respectively; 1, 5: AA, not AA, respectively. Each column
-##' contains data for a marker and each row represents an individual.}
+##' contains data for a marker and each row represents an individual.
 ##'
 ##' \item{n.ind}{number of individuals.} \item{n.mar}{number of markers.}
 ##' \item{segr.type}{a vector with the segregation type of each marker, as
@@ -52,10 +52,11 @@ globalVariables(c("mkt.wrg"))
 ##' \link{read_onemap}.} \item{input}{the name of the input file.}
 ##' \item{n.phe}{number of phenotypes.} \item{pheno}{a matrix with phenotypic
 ##' values.  Each column contains data for a trait and each row represents an
-##' individual. Currently ignored.}
+##' individual. Currently ignored.} \item{error}{matrix containing HMM emission probabilities}
+##' 
 ##' @author Adapted from Karl Broman (package \pkg{qtl}) by Marcelo Mollinari,
 ##' \email{mmollina@@usp.br}
-##' @seealso \code{mapmaker_example_bc} and \code{mapmaker_example_f2} directory in the
+##' @seealso \code{mapmaker_example_bc} and \code{mapmaker_example_f2} raw files in the
 ##' package source.
 ##' @references Broman, K. W., Wu, H., Churchill, G., Sen, S., Yandell, B.
 ##' (2008) \emph{qtl: Tools for analyzing QTL experiments} R package version
@@ -67,22 +68,22 @@ globalVariables(c("mkt.wrg"))
 ##' Report}.
 ##' @keywords IO
 ##' @examples
-##'
-##'   \dontrun{
-##'     map_data <-read_mapmaker(dir="work_directory",file="data_file.txt")
-##'     #Checking 'mapmaker_example_f2'
-##'     data(mapmaker_example_f2)
-##'     names(mapmaker_example_f2)
-##'   }
+##' \donttest{
+##'  map_data <-read_mapmaker(file=system.file("extdata/mapmaker_example_f2.raw", package = "onemap"))
+##'  #Checking 'mapmaker_example_f2'
+##'  data(mapmaker_example_f2)
+##'  names(mapmaker_example_f2)
+##' }
 ##'@export
-read_mapmaker<-function (dir, file)
+read_mapmaker<-function (file=NULL, dir=NULL, verbose=TRUE)
 {
     ## create file name
-    if (missing(file))
+    if (is.null(file))
         stop("Missing file.")
-    if (!missing(dir) && dir != "") {
+    if (!is.null(dir) && dir != "") {
         file <- file.path(dir, file)
     }
+    
     ## count lines in rawfile
     n.lines <- length(scan(file, what = character(), skip = 0,
                            nlines = 0, blank.lines.skip = FALSE,
@@ -119,10 +120,13 @@ read_mapmaker<-function (dir, file)
             n.ind <- as.numeric(a[1])
             n.mar <- as.numeric(a[2])
             n.phe <- as.numeric(a[3])
-            cat(" --Read the following data:\n")
-            cat("\tType of cross:         ", type, "\n")
-            cat("\tNumber of individuals: ", n.ind, "\n")
-            cat("\tNumber of markers:     ", n.mar, "\n")
+            if(verbose){
+                cat(" --Read the following data:\n")
+                
+                cat("\tType of cross:         ", type, "\n")
+                cat("\tNumber of individuals: ", n.ind, "\n")
+                cat("\tNumber of markers:     ", n.mar, "\n")
+            }
             ## if there's a set of "symbols" for non-standard symbols in
             ## the file, use them.
             if (length(a) > 3 && ("symbols" %in% a)) {
@@ -134,11 +138,11 @@ read_mapmaker<-function (dir, file)
                 fixed <- rep(0, length(OLD.symb))
                 for (j in 1:length(std.symb)) if (std.symb[j] %in%
                                                   OLD.symb)
-                                                  wh[j] <- match(std.symb[j], OLD.symb)
+                    wh[j] <- match(std.symb[j], OLD.symb)
                 for (j in 1:length(std.symb)) if (wh[j] != 0) {
-                                                  OLD.symb[wh[j]] <- infile.symb[j]
-                                                  fixed[wh[j]] <- 1
-                                              }
+                    OLD.symb[wh[j]] <- infile.symb[j]
+                    fixed[wh[j]] <- 1
+                }
                 temp <- table(OLD.symb)
                 if (any(temp > 1)) {
                     for (j in names(temp)[temp > 1]) {
@@ -270,10 +274,15 @@ read_mapmaker<-function (dir, file)
             else
                 segr.type[i]<-"M.X"
         }
-        segr.type.num[segr.type=="A.H.B"]<-1
-        segr.type.num[segr.type=="C.A"]<-3
-        segr.type.num[segr.type=="D.B"]<-2
-        segr.type.num[segr.type=="M.X"]<-4
+        segr.type.num[segr.type=="A.H.B"]<-4
+        segr.type.num[segr.type=="C.A"]<-7
+        segr.type.num[segr.type=="D.B"]<-6
+        segr.type.num[segr.type=="M.X"]<-0
+        # Adapting to change in f2 HMM == out HMM
+        geno[, segr.type=="C.A"][which(geno[, segr.type=="C.A"] == 1)] <- 2 
+        geno[, segr.type=="C.A"][which(geno[, segr.type=="C.A"] == 5)] <- 1 
+        geno[, segr.type=="D.B"][which(geno[, segr.type=="D.B"] == 4)] <- 1 
+        geno[, segr.type=="D.B"][which(geno[, segr.type=="D.B"] == 3)] <- 2 
         geno[is.na(geno)]<-0
     }
     else if(type=="backcross"){
@@ -282,7 +291,7 @@ read_mapmaker<-function (dir, file)
         if(sum(!is.na(unique(as.vector(geno)))) > 2)
             stop("check data: there are more than 2 classes for backcross")
         segr.type[]<-"A.H"
-        segr.type.num<-rep(NA,ncol(geno))
+        segr.type.num<-rep(8,ncol(geno))
         geno[is.na(geno)]<-0
         geno[geno==3]<-1 #coding for raw data entered as H and B
     }
@@ -293,7 +302,7 @@ read_mapmaker<-function (dir, file)
         if(sum(!is.na(unique(as.vector(geno)))) > 2)
             stop("check data: there are more than 2 classes for ", type)
         segr.type[]<-"A.B"
-        segr.type.num<-rep(NA,ncol(geno))
+        segr.type.num<-rep(9,ncol(geno))
         geno[is.na(geno)]<-0
         #geno[geno==3]<-2 #coding as backcross
     }
@@ -301,14 +310,21 @@ read_mapmaker<-function (dir, file)
         stop("Invalid cross type")
     if(n.phe != 0) {
         miss.value.pheno <- apply((apply(pheno, 2,is.na)),2,sum)
-        cat("\tMissing trait values:      ", "\n")
-        for(i in 1:n.phe) {
-            cat("\t",formatC(paste(colnames(pheno)[i],":",sep=""),width=max(nchar(paste(colnames(pheno),":",sep="")))), miss.value.pheno[i], "\n")
+        if(verbose){
+            cat("\tMissing trait values:      ", "\n")
+            for(i in 1:n.phe) {
+                cat("\t",formatC(paste(colnames(pheno)[i],":",sep=""),width=max(nchar(paste(colnames(pheno),":",sep="")))), miss.value.pheno[i], "\n")
+            }
         }
     }
-    structure(list(geno = geno, n.ind = n.ind, n.mar = n.mar,
-                   segr.type = segr.type, segr.type.num=segr.type.num,
-                   input=file, n.phe=n.phe, pheno = pheno),  class = cl)
+    
+    onemap.obj <- list(geno = geno, n.ind = n.ind, n.mar = n.mar,
+                       segr.type = segr.type, segr.type.num=segr.type.num,
+                       input=file, n.phe=n.phe, pheno = pheno)
+    class(onemap.obj) <- cl
+    new.onemap.obj <- create_probs(onemap.obj, global_error = 10^-5)
+    
+    structure(new.onemap.obj)
 }
 
 ## end of file
