@@ -1,4 +1,7 @@
 ## ----knitr_init, echo=FALSE, cache=FALSE--------------------------------------
+library(knitr)
+library(rmarkdown)
+
 knitr::opts_chunk$set(collapse = TRUE,
                       comment = "#>",
                       fig.width = 6,
